@@ -304,6 +304,7 @@ _mapper_xml = """
 """
 
 
+# noinspection SpellCheckingInspection
 def get_mapper_xml(database_info: DataBaseInfo, table_name: str) -> str:
     """
     Building XML with database description information
@@ -340,25 +341,32 @@ def get_mapper_xml(database_info: DataBaseInfo, table_name: str) -> str:
     template = env.from_string(_mapper_xml)
 
     # Assemble render parameters
-    param = {
-        "data_base_name": database_info["name"],
-        "table": database_info["table_map"][table_name]
-    }
+    data = {"data_base_name": database_info["Name"]}
+
+    # Lookup table information
+    table = None
+    for item in database_info["tables"]:
+        if item["Name"] == table_name:
+            table = item
+            break
+    if table is None:
+        return ""
+    data["table"] = table
 
     # Find primary key information
     key = ""
-    for item in param["table"]["indexs"]:
+    for item in table["indexs"]:
         if item["Name"] == "PRIMARY":
             key = item["ColumnName"]
             break
     if key is None:
         return ""
-    param["key"] = key
+    data["key"] = key
 
-    # Load supported param types
-    param["int_types"] = ["bit", "tinyint", "smallint", "mediumint", "int", "integer", "bigint"]
-    param["float_types"] = ["real", "double", "float", "decimal", "numeric"]
-    param["date_types"] = ["date", "time", "year", "timestamp", "datetime"]
-    param["string_types"] = ["char", "varchar", "text", "mediumtext", "longtext"]
+    # Load supported data types
+    data["int_types"] = ["bit", "tinyint", "smallint", "mediumint", "int", "integer", "bigint"]
+    data["float_types"] = ["real", "double", "float", "decimal", "numeric"]
+    data["date_types"] = ["date", "time", "year", "timestamp", "datetime"]
+    data["string_types"] = ["char", "varchar", "text", "mediumtext", "longtext"]
 
-    return template.render(param)
+    return template.render(data)
