@@ -9,7 +9,7 @@ from mysqlmapper.manager.mvc.service import Service
 class MySQLSessionFactory(SQLSessionFactory):
 
     # mvc holder
-    _mvc_holder = None
+    mvc_holder = None
 
     def __init__(self, conn_builder: MySQLConnBuilder, conn_handle: MySQLConnHandle, execute_engine: MySQLExecuteEngine,
                  lazy_init=True, max_conn_number=10, enable_simple_service=True, logger=DefaultLogger()):
@@ -23,53 +23,68 @@ class MySQLSessionFactory(SQLSessionFactory):
         :param enable_simple_service: enable  simple service
         :param logger: Logger
         """
-        self._mvc_holder = MVCHolder(
+        self.mvc_holder = MVCHolder(
             conn_builder.host,
             conn_builder.user,
             conn_builder.password,
             conn_builder.database,
-            enable_simple_service,
+            conn_builder.port,
             conn_builder.charset
         )
-        self._mvc_holder.set_logger(logger)
+        if enable_simple_service:
+            self.mvc_holder.load_database_service()
+        self.mvc_holder.set_logger(logger)
         super().__init__(conn_builder, conn_handle, execute_engine, lazy_init, max_conn_number, logger)
 
-    def session(self):
-        return self._mvc_holder.session
-
-    def load_service(self, table_name: str):
-        self._mvc_holder.load_service(table_name)
-        return self
+    def get_common_session(self):
+        return self.mvc_holder.session
 
     def service(self, table_name: str) -> Service:
-        return self._mvc_holder.services[table_name]
+        return self.get_simple_service(table_name)
 
-    # compatibility
-    def get_common_session(self):
-        return self._mvc_holder.session
-
-    # compatibility
     def get_simple_service(self, table_name: str) -> Service:
-        return self._mvc_holder.services[table_name]
+        return self.mvc_holder.services[table_name]
 
     def get_database_info(self):
-        return self._mvc_holder.database_info
+        return self.mvc_holder.database_info
+
+    def get_table_info(self, table_name: str):
+        if table_name not in self.mvc_holder.table_info:
+            return {}
+        return self.mvc_holder.table_info[table_name]
+
+    def load_database_service(self):
+        self.mvc_holder.load_database_service()
+        return self
+
+    def load_tables_service(self, table_names: list):
+        self.mvc_holder.load_tables_service(table_names)
+        return self
+
+    def load_table_service(self, table_name: str):
+        self.mvc_holder.load_table_service(table_name)
+        return self
+
+    def load_service(self, database_info: dict):
+        self.mvc_holder.load_service(database_info)
+        return self
 
 
 class MySQLSessionFactoryBuild(SQLSessionFactoryBuild):
 
     _enable_simple_service = True
 
-    def __init__(self, host: str, user: str, password: str, database: str, charset="utf8"):
+    def __init__(self, host: str, user: str, password: str, database: str, port=3306, charset="utf8"):
         """
         Init
         :param host: host
         :param user: user
         :param password: password
         :param database: database
+        :param port: data source port
         :param charset: charset
         """
-        conn_builder = MySQLConnBuilder(host, user, password, database, charset)
+        conn_builder = MySQLConnBuilder(host, user, password, database, port, charset)
         super().__init__(conn_builder, MySQLConnHandle(), MySQLExecuteEngine())
 
     def close_simple_service(self):
